@@ -20,6 +20,12 @@ sibling = '[[!my $sibling=#ONT(sibling)]]'
 work = '[[!my {work,job,boss}]]'
 school = '[[!my {school,college,university}]]'
 pet = '[my cat]'
+repeat = '{' \
+         '[![!{can,will,could} you]? repeat, {that,what you said,you said}?],' \
+         '[![!{can,will,could} you]? say {that,it} again],' \
+         '[!what did you, just? say],' \
+         '[!what was that]' \
+         '} #COPY(__goal_return_state__)'
 
 global_update_rules = {
     '#CONTRACTIONS': '',
@@ -29,5 +35,5 @@ global_update_rules = {
     work: '#SET($is_employed=True)',
     school: '#SET($is_student=True)',
     pet:'',
-    '[!repeat] #COPY(__goal_return_state__)': '#REPEAT (15.0)'
+    repeat: '#REPEAT (15.0)'
 }
\ No newline at end of file
